@@ -2,7 +2,7 @@
 package RPerl::Config;
 use strict;
 use warnings;
-our $VERSION = 0.003_031;
+our $VERSION = 0.003_040;
 
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
@@ -256,8 +256,9 @@ my $rperls_found    = [];
 my $rperl_pms_found = [];
 
 # BULK88 20150608 2015.159: Win32 Bug Fix
-#foreach my $inc_path ( $directories_loaded, @INC ) {
-foreach my $inc_path ( File::Spec->catpath( $volume_loaded, $directories_loaded, '' ), @INC ) {
+#foreach my $inc_path ( $directories_loaded, @INC ) {  # this doesn't work with Win32
+# DEV NOTE: search order precedence for `rperl` command is OS paths, path of loaded RPerl/Config.pm (this file), Perl INC paths
+foreach my $inc_path ( (split ':', $ENV{PATH}), File::Spec->catpath( $volume_loaded, $directories_loaded, '' ), @INC ) {
 
     #    print {*STDERR} 'in RPerl::Config, top of main foreach() loop, have $inc_path = ', $inc_path, "\n";
     my $sub_inc_paths = [];
