@@ -1,8 +1,8 @@
 ## no critic qw(ProhibitUselessNoCritic PodSpelling ProhibitExcessMainComplexity
 
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPARP00' >>>
-# <<< COMPILE_ERROR: 'Unexpected token:  package' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPARP00' >>>
+# <<< PARSE_ERROR: 'Unexpected Token:  package' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::Critic::Class_01_Bad_03;
@@ -19,11 +19,12 @@ use RPerl::Test;
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 
 # [[[ OO PROPERTIES ]]]
-our %properties = ( ## no critic qw(ProhibitPackageVars)  # USER DEFAULT 3: allow OO properties
-    empty_property => my integer $TYPED_empty_property = 2
-);
+our hashref $properties
+    = { empty_property => my integer $TYPED_empty_property = 2 };
 
-# [[[ OO METHODS ]]]
-our void__method $empty_method = sub { return 2; };
+# [[[ OO METHODS & SUBROUTINES ]]]
+our void_method $empty_method = sub {
+    return 2;
+};
 
 1;                  # end of class
