@@ -1,6 +1,6 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPAPL02' >>>
-# <<< COMPILE_ERROR: 'near "use RPer:"' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPAPL02' >>>
+# <<< PARSE_ERROR: 'near "use RPer:"' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::Include::Class_00_Bad_02;
@@ -18,11 +18,12 @@ use RPer:Test::Foo;
 use RPerl::Test::Bar;
 
 # [[[ OO PROPERTIES ]]]
-our %properties = ( ## no critic qw(ProhibitPackageVars)  # USER DEFAULT 3: allow OO properties
-    empty_property => my integer $TYPED_empty_property = 2
-);
+our hashref $properties
+    = { empty_property => my integer $TYPED_empty_property = 2 };
 
-# [[[ OO METHODS ]]]
-our void__method $empty_method = sub { return 2; };
+# [[[ OO METHODS & SUBROUTINES ]]]
+our void_method $empty_method = sub {
+    return 2;
+};
 
 1;                  # end of class
