@@ -1,6 +1,6 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPARP00' >>>
-# <<< COMPILE_ERROR: 'Unexpected token:  use' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPARP00' >>>
+# <<< PARSE_ERROR: 'Unexpected Token:  use' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::Include::Class_00_Bad_09;
@@ -17,12 +17,13 @@ use RPerl::Test;
 use RPerl::Test::Foo;
 
 # [[[ OO PROPERTIES ]]]
-our %properties = ( ## no critic qw(ProhibitPackageVars)  # USER DEFAULT 3: allow OO properties
-    empty_property => my integer $TYPED_empty_property = 2
-);
+our hashref $properties
+    = { empty_property => my integer $TYPED_empty_property = 2 };
 
-# [[[ OO METHODS ]]]
-our void__method $empty_method = sub { return 2; };
+# [[[ OO METHODS & SUBROUTINES ]]]
+our void_method $empty_method = sub {
+    return 2;
+};
 
 use RPerl::Test::Bar;
 
