@@ -1,6 +1,6 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPAPL02' >>>
-# <<< COMPILE_ERROR: 'near "use RPerl:"' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPAPL02' >>>
+# <<< PARSE_ERROR: 'near "use RPerl:"' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::Include::Package_00_Bad_01;
@@ -14,6 +14,8 @@ use RPerl:Test::Foo;
 use RPerl::Test::Bar;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub { return 2; };
+our void $empty_sub = sub {
+    return 2;
+};
 
 1;                  # end of package
