@@ -1,6 +1,6 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPAPL02' >>>
-# <<< COMPILE_ERROR: 'Can't locate RPerl/Tst/Bar.pm' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPAPL02' >>>
+# <<< PARSE_ERROR: 'Can't locate RPerl/Tst/Bar.pm' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::Include::Package_00_Bad_02;
@@ -14,6 +14,8 @@ use RPerl::Test::Foo;
 use RPerl::Tst::Bar;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub { return 2; };
+our void $empty_sub = sub {
+    return 2;
+};
 
 1;                  # end of package
