@@ -1,6 +1,6 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPAPL02' >>>
-# <<< COMPILE_ERROR: 'Can't modify constant item in predecrement' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPAPL02' >>>
+# <<< PARSE_ERROR: 'Can't modify constant item in predecrement' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::LiteralNumber::Package_31_Bad_00;
@@ -13,6 +13,8 @@ our $VERSION = 0.001_000;
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub { return --0.234_567_89; };
+our number $empty_sub = sub {
+    return --0.234_567_89;
+};
 
-1;                  # end of package
+1;    # end of package
