@@ -9,6 +9,8 @@ our $VERSION = 0.001_000;
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub { return -23_456_789.234_56; };
+our number $empty_sub = sub {
+    return -23_456_789.234_56;
+};
 
-1;                  # end of package
+1;    # end of package
