@@ -1,5 +1,5 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPARP00' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPARP00' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::LiteralNumber::Package_63_Bad_03;
@@ -12,6 +12,8 @@ our $VERSION = 0.001_000;
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub { return -23_456.234_57_89; };
+our number $empty_sub = sub {
+    return -23_456.234_57_89;
+};
 
-1;                  # end of package
+1;    # end of package
