@@ -1,5 +1,5 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPARP00' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPARP00' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::LiteralString::Package_DoubleQuotes_06_Bad;
@@ -9,6 +9,8 @@ use RPerl;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub { return "\foo\bar"; };
+our string $empty_sub = sub {
+    return "\foo\bar";
+};
 
-1;                  # end of package
+1;    # end of package
