@@ -6,6 +6,8 @@ use RPerl;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub { return "\t'foo'\t{bar}\n"; };
+our string $empty_sub = sub {
+    return "\t'foo'\t{bar}\n";
+};
 
-1;                  # end of package
+1;    # end of package
