@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPAPL02' >>>
-# <<< COMPILE_ERROR: 'near "sine 2"' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPAPL02' >>>
+# <<< PARSE_ERROR: 'near "sine 2"' >>>
 
 # [[[ HEADER ]]]
 use strict;
@@ -20,7 +20,7 @@ our $VERSION = 0.001_000;
 my number $op_sin = sine 2;
 my number $op_cos = cos 2;
 
-my integer__array_ref $frob = [];
+my integer_arrayref $frob = [];
 my integer $frob_length = ( push @{$frob}, 21, 12, 23 ); # Operator, yes parentheses required for builtin w/ multiple arguments in non-void context
 print 'have $frob_length = ', $frob_length, "\n";
 print 'have $frob = ', "\n", Dumper($frob), "\n";
