@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPAPL02' >>>
-# <<< COMPILE_ERROR: 'Global symbol "$HOWD" requires explicit package name' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPAPL02' >>>
+# <<< PARSE_ERROR: 'Global symbol "$HOWD" requires explicit package name' >>>
 
 # [[[ HEADER ]]]
 use strict;
@@ -17,7 +17,7 @@ our $VERSION = 0.001_000;
 
 # USER NOTE: the Operator (not OperatorVoid) production rule matched by 'print' requires parentheses and filehandle
 
-my integer $open_success = open my filehandle_ref $HOWDY, '>', '/tmp/howdy';
+my integer $open_success = open my filehandleref $HOWDY, '>', '/tmp/howdy';
 if ( not $open_success ) {
     croak 'ERROR: Failed to open file /tmp/howdy for writing, croaking';
 }
