@@ -1,6 +1,6 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPAPL02' >>>
-# <<< COMPILE_ERROR: 'syntax error' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPAPL02' >>>
+# <<< PARSE_ERROR: 'syntax error' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::Subroutine::Package_00_Bad_03;
@@ -10,6 +10,8 @@ use RPerl;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub  sub { return 2; };
+our void $empty_sub  sub {
+    return 2;
+};
 
 1;                  # end of package
