@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
 # [[[ PREPROCESSOR ]]]
-# <<< RUN_ERROR: 'ERROR EIVAVRV03, TYPE-CHECKING MISMATCH' >>>
-# <<< RUN_ERROR: 'integer__array_ref element value expected but non-integer value found at index 3' >>>
+# <<< EXECUTE_ERROR: 'ERROR EIVAVRV03, TYPE-CHECKING MISMATCH' >>>
+# <<< EXECUTE_ERROR: 'integer_arrayref element value expected but non-integer value found at index 3' >>>
 
 # [[[ HEADER ]]]
 use strict;
@@ -17,4 +17,4 @@ our $VERSION = 0.000_001;
 use RPerl::Test::TypeCheckingOn::AllTypes;
 
 # [[[ OPERATIONS ]]]
-check__integer__array_ref( [ -999_999, 3, 4, { a => 0, b => 1, c => 2 } ] );
+check_integer_arrayref( [ -999_999, 3, 4, { a => 0, b => 1, c => 2 } ] );
