@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
 # [[[ PREPROCESSOR ]]]
-# <<< RUN_ERROR: 'ERROR EIV01, TYPE-CHECKING MISMATCH' >>>
-# <<< RUN_ERROR: 'integer value expected but non-integer value found' >>>
+# <<< EXECUTE_ERROR: 'ERROR EIV01, TYPE-CHECKING MISMATCH' >>>
+# <<< EXECUTE_ERROR: 'integer value expected but non-integer value found' >>>
 
 # [[[ HEADER ]]]
 use strict;
@@ -17,4 +17,4 @@ our $VERSION = 0.000_001;
 use RPerl::Test::TypeCheckingOn::AllTypes;
 
 # [[[ OPERATIONS ]]]
-check__integer(0.123);
+check_integer(0.123);
