@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
 # [[[ PREPROCESSOR ]]]
-# <<< RUN_ERROR: 'ERROR EPVAVRV03, TYPE-CHECKING MISMATCH' >>>
-# <<< RUN_ERROR: 'string__array_ref element value expected but non-string value found at index 3' >>>
+# <<< EXECUTE_ERROR: 'ERROR EPVAVRV03, TYPE-CHECKING MISMATCH' >>>
+# <<< EXECUTE_ERROR: 'string_arrayref element value expected but non-string value found at index 3' >>>
 
 # [[[ HEADER ]]]
 use strict;
@@ -17,4 +17,4 @@ our $VERSION = 0.000_001;
 use RPerl::Test::TypeCheckingOn::AllTypes;
 
 # [[[ OPERATIONS ]]]
-check__string__array_ref( [ 'hello', 'howdy', 'ahoy', -999_999.123_456 ] );
+check_string_arrayref( [ 'hello', 'howdy', 'ahoy', -999_999.123_456 ] );
